@@ -1,5 +1,3 @@
-import sys
-
 import branca
 from branca.colormap import ColorMap, LinearColormap, StepColormap
 from branca.element import (
@@ -34,6 +32,7 @@ from folium.folium import Map
 from folium.map import (
     FeatureGroup,
     FitBounds,
+    FitOverlays,
     Icon,
     LayerControl,
     Marker,
@@ -41,6 +40,7 @@ from folium.map import (
     Tooltip,
 )
 from folium.raster_layers import TileLayer, WmsTileLayer
+from folium.utilities import JsCode
 from folium.vector_layers import Circle, CircleMarker, Polygon, PolyLine, Rectangle
 
 try:
@@ -58,29 +58,6 @@ if branca.__version__ != "unknown" and tuple(
     )
 
 
-if sys.version_info < (3, 0):
-    raise ImportError(
-        """You are running folium {} on Python 2
-
-    folium 0.9 and above are no longer compatible with Python 2, but somehow
-    you got this version anyway. Make sure you have pip >= 9.0 to avoid this
-    kind of issue, as well as setuptools >= 24.2:
-
-     $ pip install pip setuptools --upgrade
-
-    Your choices:
-
-    - Upgrade to Python 3.
-
-    - Install an older version of folium:
-
-     $ pip install 'folium<0.9.0'
-
-    """.format(
-            __version__
-        )
-    )  # noqa
-
 __all__ = [
     "Choropleth",
     "ClickForMarker",
@@ -95,6 +72,7 @@ __all__ = [
     "FeatureGroup",
     "Figure",
     "FitBounds",
+    "FitOverlays",
     "GeoJson",
     "GeoJsonPopup",
     "GeoJsonTooltip",
@@ -102,6 +80,7 @@ __all__ = [
     "IFrame",
     "Icon",
     "JavascriptLink",
+    "JsCode",
     "LatLngPopup",
     "LayerControl",
     "LinearColormap",
