@@ -1,7 +1,6 @@
-from jinja2 import Template
-
 from folium.elements import JSCSSMixin
 from folium.map import Layer
+from folium.template import Template
 
 
 class FeatureGroupSubGroup(JSCSSMixin, Layer):
@@ -23,7 +22,7 @@ class FeatureGroupSubGroup(JSCSSMixin, Layer):
     control : bool, default True
         Whether the Layer will be included in LayerControls.
     show: bool, default True
-        Whether the layer will be shown on opening (only for overlays).
+        Whether the layer will be shown on opening.
 
     Examples
     -------
@@ -61,7 +60,6 @@ class FeatureGroupSubGroup(JSCSSMixin, Layer):
             var {{ this.get_name() }} = L.featureGroup.subGroup(
                 {{ this._group.get_name() }}
             );
-            {{ this.get_name() }}.addTo({{ this._parent.get_name() }});
         {% endmacro %}
         """
     )
