@@ -4,10 +4,10 @@ Based on leaflet plugin: https://github.com/domoritz/leaflet-locatecontrol
 """
 
 from branca.element import MacroElement
-from jinja2 import Template
 
 from folium.elements import JSCSSMixin
-from folium.utilities import parse_options
+from folium.template import Template
+from folium.utilities import remove_empty
 
 
 class LocateControl(JSCSSMixin, MacroElement):
@@ -74,4 +74,4 @@ class LocateControl(JSCSSMixin, MacroElement):
         super().__init__()
         self._name = "LocateControl"
         self.auto_start = auto_start
-        self.options = parse_options(**kwargs)
+        self.options = remove_empty(**kwargs)
