@@ -1,8 +1,8 @@
 from branca.element import MacroElement
-from jinja2 import Template
 
 from folium.elements import JSCSSMixin
-from folium.utilities import parse_options
+from folium.template import Template
+from folium.utilities import remove_empty
 
 
 class MeasureControl(JSCSSMixin, MacroElement):
@@ -25,9 +25,24 @@ class MeasureControl(JSCSSMixin, MacroElement):
         """
         {% macro script(this, kwargs) %}
             var {{ this.get_name() }} = new L.Control.Measure(
-                {{ this.options|tojson }});
+                {{ this.options|tojavascript }});
             {{this._parent.get_name()}}.addControl({{this.get_name()}});
 
+            // Workaround for using this plugin with Leaflet>=1.8.0
+            // https://github.com/ljagis/leaflet-measure/issues/171
+            L.Control.Measure.include({
+                _setCaptureMarkerIcon: function () {
+                    // disable autopan
+                    this._captureMarker.options.autoPanOnFocus = false;
+                    // default function
+                    this._captureMarker.setIcon(
+                        L.divIcon({
+                            iconSize: this._map.getSize().multiplyBy(2)
+                        })
+                    );
+                },
+            });
+
         {% endmacro %}
         """
     )  # noqa
@@ -55,11 +70,10 @@ class MeasureControl(JSCSSMixin, MacroElement):
         secondary_area_unit="acres",
         **kwargs
     ):
-
         super().__init__()
         self._name = "MeasureControl"
 
-        self.options = parse_options(
+        self.options = remove_empty(
             position=position,
             primary_length_unit=primary_length_unit,
             secondary_length_unit=secondary_length_unit,
