@@ -1,11 +1,11 @@
 from branca.element import MacroElement
-from jinja2 import Template
 
 from folium import Map
 from folium.elements import JSCSSMixin
 from folium.features import FeatureGroup, GeoJson, TopoJson
 from folium.plugins import MarkerCluster
-from folium.utilities import parse_options
+from folium.template import Template
+from folium.utilities import remove_empty
 
 
 class Search(JSCSSMixin, MacroElement):
@@ -69,7 +69,7 @@ class Search(JSCSSMixin, MacroElement):
                         return feature.properties.style
                     })
                     {% if this.options %}
-                    e.layer.setStyle({{ this.options|tojson }});
+                    e.layer.setStyle({{ this.options|tojavascript }});
                     {% endif %}
                     if(e.layer._popup)
                         e.layer.openPopup();
@@ -107,7 +107,7 @@ class Search(JSCSSMixin, MacroElement):
         position="topleft",
         placeholder="Search",
         collapsed=False,
-        **kwargs
+        **kwargs,
     ):
         super().__init__()
         assert isinstance(layer, (GeoJson, MarkerCluster, FeatureGroup, TopoJson)), (
@@ -122,14 +122,12 @@ class Search(JSCSSMixin, MacroElement):
         self.position = position
         self.placeholder = placeholder
         self.collapsed = collapsed
-        self.options = parse_options(**kwargs)
+        self.options = remove_empty(**kwargs)
 
     def test_params(self, keys):
         if keys is not None and self.search_label is not None:
             assert self.search_label in keys, (
-                "The label '{}' was not "
-                "available in {}"
-                "".format(self.search_label, keys)
+                f"The label '{self.search_label}' was not " f"available in {keys}" ""
             )
         assert isinstance(
             self._parent, Map
