@@ -1,11 +1,11 @@
 import json
 
 from branca.element import MacroElement
-from jinja2 import Template
 
 from folium.elements import JSCSSMixin
 from folium.folium import Map
-from folium.utilities import get_bounds, parse_options
+from folium.template import Template
+from folium.utilities import get_bounds, remove_empty
 
 
 class TimestampedGeoJson(JSCSSMixin, MacroElement):
@@ -94,7 +94,7 @@ class TimestampedGeoJson(JSCSSMixin, MacroElement):
                 }
             );
             var timeDimensionControl = new L.Control.TimeDimensionCustom(
-                {{ this.options|tojson }}
+                {{ this.options|tojavascript }}
             );
             {{this._parent.get_name()}}.addControl(this.timeDimensionControl);
 
@@ -146,8 +146,8 @@ class TimestampedGeoJson(JSCSSMixin, MacroElement):
 
     default_js = [
         (
-            "jquery2.0.0",
-            "https://cdnjs.cloudflare.com/ajax/libs/jquery/2.0.0/jquery.min.js",
+            "jquery3.7.1",
+            "https://cdnjs.cloudflare.com/ajax/libs/jquery/3.7.1/jquery.min.js",
         ),
         (
             "jqueryui1.10.2",
@@ -211,7 +211,7 @@ class TimestampedGeoJson(JSCSSMixin, MacroElement):
         self.date_options = date_options
         self.duration = "undefined" if duration is None else '"' + duration + '"'
 
-        self.options = parse_options(
+        self.options = remove_empty(
             position="bottomleft",
             min_speed=min_speed,
             max_speed=max_speed,
